Slot: name - LinkML Model

# Slot: name

the unique name of the element within the context of the schema. Name is combined with the default prefix to form the globally unique subject of the target class.

URI: linkml:name

## Domain and Range

Element → 1..1 String

## Parents

## Children

- schema_definition➞name

## Used by

- ClassDefinition
- Definition
- Element
- EnumDefinition
- SlotDefinition
- SubsetDefinition
- TypeDefinition

## Other properties

Mappings: |  | rdfs:label
|  | schema:name
In Subsets: |  | owl
See also: |  | https://en.wikipedia.org/wiki/Data_element_name